@@ -25,14 +25,15 @@ our %MAP       = (
 );
 
 my %regexes = (
-    no_user_id => qr/\>No userid found\</i,
-    next_id    => qr/sc\?id\=(.*?)\"\>/i,
-    http_500   => qr/500/,
+    no_user_id    => qr/\>No userid found\</i,
+    next_id       => qr/sc\?id\=(.*?)\"\>/i,
+    http_500      => qr/500/,
+    too_old_email => qr/Sorry, this email is too old/i,
 );
 
 lock_hash(%MAP);
 
-our $VERSION = '0.8'; # VERSION
+our $VERSION = '0.9'; # VERSION
 
 =head1 NAME
 
@@ -419,17 +420,10 @@ sub main_loop {
         return 0;
     }
 
-    my $html = $res->content;
-
-    if ( my $error_msg = _check_error( \$html ) ) {
-        $logger->fatal($error_msg);
-        return 0;
+    if ( my $error_msg = _check_error( \( $res->content ) ) ) {
+        $logger->error($error_msg);
     }
 
-# :WORKAROUND:12/02/2018 22:20:49:ARFREITAS: ugly, but works meanwhile getting a SPAM
-# is not a sub for itself.
-    $html = undef;
-
     # parse the spam
     my $_cancel  = 0;
     my $base_uri = $res->base();
@@ -443,8 +437,20 @@ sub main_loop {
 # :TODO:07/02/2018 10:17:30:ARFREITAS: too many regexes being compiled repeated times, compile than once and reuse them later!
     $res->content =~
       /(\<form action[^>]+name=\"sendreport\"\>.*?\<\/form\>)/sgi;
-    my $formdata = "<html><body>$1</body></html>";
-    my $form = HTML::Form->parse( $formdata, $base_uri );
+    my $form_data = $1;
+
+    if ( defined($form_data) ) {
+        $form_data = "<html><body>$1</body></html>";
+    }
+    else {
+        $logger->error('Could not parse form data from HTTP response');
+
+        # :WORKAROUND:18/02/2018 14:20:17:ARFREITAS: to avoid warnings
+        $form_data = '';
+    }
+
+    # :TODO:18/02/2018 14:19:49:ARFREITAS: refactor to make form parsing a sub
+    my $form = HTML::Form->parse( $form_data, $base_uri );
 
     if ( $res->content =~
 /Please make sure this email IS spam.*?size=2\>\n(.*?)\<a href\=\"\/sc\?id\=$next_id/sgi
@@ -453,13 +459,12 @@ sub main_loop {
 
         if ( $logger->is_info ) {
             my $spamhead = decode_entities($1);
-            $logger->info('Head of the SPAM follows');
             $spamhead =~ s/\n/\t/igs;    # prepend a tab to each line
             $spamhead =~ s/<\/?strong>//gi;
             $spamhead =~ s/<br>/\n/gsi;
             $spamhead =~ s/<\/?font>//gi;
             binmode( STDOUT, ":utf8" );
-            $logger->info($spamhead);
+            $logger->info("Head of the SPAM follows:\n$spamhead");
         }
 
         # parse form fields
@@ -580,20 +585,9 @@ sub main_loop {
 
     }
 
-# :TODO:11/02/2018 11:05:04:ARFREITAS: capture the message and provide it without manipulation
-#<div class="error">Sorry, this email is too old to file a spam report. You must report spam within 2 days of receipt. This mail was received on Fri, 9 Feb 2018 04:30:56 -0800</div>
-#Message is 2.0 days old<br>
-    elsif ( $res->content =~
-/Sorry, this email is too old.*This mail was received on (.*?)\<\/.*\>/gsi
-      )
-    {
-        # perhaps it's too old then
-        my $ondate = $1;
-        $logger->warn(
-"This SPAM is too old. You must report SPAM within 3 days of receipt. This mail was received on $ondate. Deleted."
-        );
+    elsif ( $res->content =~ $regexes{too_old_email} ) {
+        $logger->warn('This SPAM is too old and thus was deleted.');
         return 0;
-
     }
     elsif ( $res->content =~
 /click reload if this page does not refresh automatically in \n(\d+) seconds/gs
